@@ -17,6 +17,33 @@ from opencos import util, export_helper
 from opencos.eda_base import CommandDesign, Tool
 from opencos.utils import status_constants
 
+from opencos.utils.str_helpers import sanitize_defines_for_sh, strip_outer_quotes
+
+def parameters_dict_get_command_list(params: dict, arg_prefix: str = '-G') -> list:
+    '''Given dict of parameters, returns a command list'''
+
+    ret_list = []
+    if ' ' in arg_prefix:
+        arg_list_prefix = arg_prefix.split()
+        arg_str_prefix = ''
+    else:
+        arg_list_prefix = []
+        arg_str_prefix = arg_prefix
+
+    for k,v in params.items():
+        if not isinstance(v, (int, str)):
+            util.warning(f'parameter {k} has value: {v}, parameters must be int/string types')
+
+        ret_list.extend(arg_list_prefix)
+        if isinstance(v, int):
+            ret_list.append(f'{arg_str_prefix}{k}={v}')
+        else: # string
+            v = strip_outer_quotes(v.strip('\n'))
+            v = '"' + v + '"'
+            ret_list.append(f'{arg_str_prefix}{k}={sanitize_defines_for_sh(v)}')
+    return ret_list
+
+
 class CommandSim(CommandDesign):
     '''Base class command handler for: eda sim ...'''
 
@@ -80,6 +107,10 @@ class CommandSim(CommandDesign):
 
         self.args['verilate-args'] = []
 
+    def process_parameters_get_list(self, arg_prefix: str = '-G') -> list:
+        '''Returns list (suitable command list for shell or for tool) from self.parameters'''
+        return parameters_dict_get_command_list(params=self.parameters, arg_prefix=arg_prefix)
+
     def process_plusarg(self, plusarg: str, pwd: str = os.getcwd()) -> None:
         '''Override for CommandDesign.process_plusarg(..)'''
         maybe_plusarg = CommandDesign.process_plusarg(self, plusarg, pwd)
