@@ -91,6 +91,22 @@ class DepsProcessor: # pylint: disable=too-many-instance-attributes
                         v = v.replace('%SEED%', str(self.args.get('seed', 1)))
                 self.command_design_ref.process_plusarg(f'+define+{k}={v}')
 
+
+    def apply_parameters(self, parameters_dict: dict):
+        '''Given parameters_dict, applies them to our self.command_design_ref obj'''
+        if not isinstance(parameters_dict, dict):
+            self.error(f"{parameters_dict=} is not type dict, can't apply defines,",
+                       f"in {self.caller_info}")
+        for k,v in parameters_dict.items():
+            if v is None or v == '' or not isinstance(v, (int, str, bool)):
+                warning(f'parameter {k} has value: {v}, parameters must be bool/int/string types',
+                        f'from {self.caller_info}')
+            else:
+                self.command_design_ref.set_parameter(
+                    name=k, value=v, caller_info=self.caller_info
+                )
+
+
     def apply_incdirs(self, incdirs_list:list):
         '''Given incdirs_list, applies them to our self.command_design_ref obj'''
         if not isinstance(incdirs_list, (str, list)):
@@ -252,6 +268,8 @@ class DepsProcessor: # pylint: disable=too-many-instance-attributes
                 remaining_deps_list += self.process_tags()
             elif key == 'defines':
                 self.process_defines()
+            elif key == 'parameters':
+                self.process_parameters()
             elif key == 'incdirs':
                 self.process_incdirs()
             elif key == 'top':
@@ -426,6 +444,9 @@ class DepsProcessor: # pylint: disable=too-many-instance-attributes
                         # apply defines:
                         self.apply_defines(value.get('defines', {}))
 
+                    elif key == 'parameters':
+                        self.apply_parameters(value.get('parameters', {}))
+
                     elif key == 'incdirs':
                         # apply incdirs:
                         self.apply_incdirs(value.get('incdirs', []))
@@ -517,6 +538,22 @@ class DepsProcessor: # pylint: disable=too-many-instance-attributes
 
         self.apply_defines(entry_defines)
 
+    def process_parameters(self):
+        '''Returns None, applies parameters (dict, if any) from self.deps_entry to
+        self.command_design_ref.'''
+
+        # Parameters:
+        # apply command specific parameters, with higher priority than the a
+        # deps_entry['sim']['parameters'] entry,
+        # do this with dict1.update(dict2):
+        entry_parameters = {}
+        entry_parameters.update(self.deps_entry.get('parameters', {}))
+        entry_parameters.update(self.entry_eda_command.get('parameters', {}))
+        assert isinstance(entry_parameters, dict), \
+            f'{entry_parameters=} for in {self.caller_info} must be a dict'
+
+        self.apply_parameters(entry_parameters)
+
     def process_incdirs(self) -> None:
         '''Returns None, applies incdirs (dict, if any) from self.deps_entry to
         self.command_design_ref.'''
@@ -700,7 +737,8 @@ class DepsProcessor: # pylint: disable=too-many-instance-attributes
                 deps_targets_to_resolve.append(command_tuple)
 
 
-            elif isinstance(dep, str) and any(dep.startswith(x) for x in ['+define+', '+incdir']):
+            elif isinstance(dep, str) and \
+                 any(dep.startswith(x) for x in ['+define+', '+incdir+']):
                 # Note: we still support +define+ and +incdir in the deps list.
                 # check for compile-time Verilog style plusarg, which are supported under targets
                 # These are not run-time Verilog style plusargs comsumable from within the .sv:
