@@ -49,6 +49,9 @@ def init_config(
 
     # For key DEFAULT_HANDLERS, we'll update config['command_handler'] with
     # the actual class using importlib (via opencos.util)
+
+    eda_config.tool_try_add_to_path(tool)
+
     config['command_handler'] = {}
     for _cmd, str_class in config['DEFAULT_HANDLERS'].items():
         cls = util.import_class_from_string(str_class)
@@ -329,7 +332,7 @@ def tool_setup(tool: str, config: dict, quiet: bool = False, auto_setup: bool =
     config['tools_loaded'].add(tool)
 
 
-def process_tokens( # pylint: disable=too-many-branches,too-many-statements,too-many-locals
+def process_tokens( # pylint: disable=too-many-branches,too-many-statements,too-many-locals,too-many-return-statements
         tokens: list, original_args: list, config: dict, is_interactive=False
 ) -> int:
     '''Returns bash/sh style return code int (0 pass, non-zero fail).
@@ -416,6 +419,15 @@ def process_tokens( # pylint: disable=too-many-branches,too-many-statements,too-
         return 2
 
     sco = config['command_handler'][command](config=config) # sub command object
+    if not parsed.tool:
+        # then what was the auto selected tool?
+        sco_tool = getattr(sco, '_TOOL', '')
+        if sco_tool in config['auto_tools_order'][0] and \
+           config['auto_tools_order'][0][sco_tool].get('disable-auto', False):
+            util.error(f'Cannot use tool={sco_tool} without arg --tool, it cannot be selected',
+                       'automatically')
+            return status_constants.EDA_COMMAND_OR_ARGS_ERROR
+
     util.debug(f'{command=}')
     util.debug(f'{sco.config=}')
     util.debug(f'{type(sco)=}')
