@@ -286,7 +286,11 @@ def get_list_sv_included_files(
         # If we have more than N levels of `include hunting, then rethink this.
         # For example, some codebases would do their file dependencies as `include
         # as part of their header guards, which could be ~100 levels of nesting.
-        for fname,traversed in sv_included_files_dict.items():
+
+        # make a copy of keys so we don't alter during traversal of the dict:
+        fnames = list(sv_included_files_dict.keys())
+        for fname in fnames:
+            traversed = sv_included_files_dict[fname]
             if not traversed:
                 included_files_list = find_sv_included_files_within_file(
                     filename=fname,
