@@ -100,9 +100,34 @@ class CommandSimCocotb(CommandSim, ToolCocotb):
     def set_tool_defines(self):
         ToolCocotb.set_tool_defines(self)
 
+    def help( # pylint: disable=dangerous-default-value
+            self, tokens: list = [], no_targets: bool = False
+    ) -> None:
+        '''Override for Command.help(...)'''
+
+        super().help(tokens=tokens, no_targets=no_targets)
+        self._warn_if_simulator_not_present()
+
+    def _warn_if_simulator_not_present(self) -> None:
+        '''Warn if --cocotb-simulator is not set, or if the exe is not in PATH'''
+
+        simulator = self.args['cocotb-simulator']
+        if not simulator:
+            util.warning('--cocotb-simulator is not set, a simulation cannot be run with'
+                         'this arg value')
+            return
+        exe = shutil.which(simulator)
+        if not exe:
+            util.warning(f'--cocotb-simulator={simulator}, {simulator} is not present in PATH',
+                         'a simulation cannot be run with this arg value')
+
+
     def prepare_compile(self):
         self.set_tool_defines()
 
+        # Check existence of cocotb-simulator:
+        self._warn_if_simulator_not_present()
+
         # Fix iverilog -> icarus
         if self.args['cocotb-simulator'] == 'iverilog':
             self.args['cocotb-simulator'] = 'icarus'
