@@ -10,7 +10,7 @@ Note that this is for 32-bit Modelsim Student Edition. Consider using --tool=que
 import os
 
 from opencos import util
-from opencos.commands import CommandSim
+from opencos.commands import sim, CommandSim
 from opencos.tools.questa import ToolQuesta
 from opencos.utils.str_helpers import sanitize_defines_for_sh
 
@@ -201,6 +201,44 @@ class CommandSimModelsimAse(CommandSim, ToolModelsimAse):
         with open(vlog_dot_f_fpath, 'w', encoding='utf-8') as f:
             f.writelines(line + "\n" for line in vlog_dot_f_lines)
 
+    def vopt_handle_parameters(self) -> (str, list):
+        '''Returns str for vopt or voptargs, and list of vopt tcl
+
+        Note this is used for self.use_vopt = True or False.
+        '''
+
+        voptargs_str = ''
+        vopt_do_lines = []
+
+        # Note that if self.use_vopt=True, we have to do some workarounds for how
+        # some questa-like tools behave for: tcl/.do + vopt arg processing
+        # This affects string based parameters that have spaces (vopt treats spaces unique args,
+        # vsim does not). Since we'd like to keep the vopt/vsim split into separate steps, we can
+        # work around this by setting tcl varaibles for each parameter.
+        if self.parameters:
+            if not self.use_vopt:
+                voptargs_str += ' ' + ' '.join(self.process_parameters_get_list(arg_prefix='-G'))
+            else:
+                for k,v in self.parameters.items():
+                    s = sim.parameters_dict_get_command_list(params={k: v}, arg_prefix='')[0]
+                    # At this point, s should be a str in form {k}={v}
+                    if not s or '=' not in s:
+                        continue
+                    if ' ' in s:
+                        # Instead of:
+                        #   vopt -GMyParam="hi bye"
+                        # we'll do:
+                        #   set PARAMETERS(MyParam) "hi bye"
+                        #  vopt -GMyParam=$PARAMETERS(MyParam)
+                        s = s.replace(f'{k}=', f'set PARAMETERS({k}) ')
+                        vopt_do_lines.append(s)
+                        voptargs_str += f' -G{k}=$PARAMETERS({k}) '
+                    else:
+                        voptargs_str += f' -G{s} '
+
+        return voptargs_str, vopt_do_lines
+
+
     def write_vsim_dot_do( # pylint: disable=too-many-locals
             self, dot_do_to_write: list
     ) -> None:
@@ -223,9 +261,13 @@ class CommandSimModelsimAse(CommandSim, ToolModelsimAse):
                 typ='waveform', description='Modelsim/Questa Waveform WLF (Wave Log Format) file'
             )
 
-        # parameters
-        if self.parameters:
-            voptargs_str += ' ' + ' '.join(self.process_parameters_get_list(arg_prefix='-G'))
+        vlog_do_lines = []
+        vsim_do_lines = []
+
+        # parameters, use helper method to get voptargs_str and vopt_do_lines
+        more_voptargs_str, vopt_do_lines = self.vopt_handle_parameters()
+        voptargs_str += more_voptargs_str
+
 
         # TODO(drew): support self.args['sim_libary', 'elab-args', sim-args'] (3 lists)
         # to add to vsim_one_liner.
@@ -251,7 +293,7 @@ class CommandSimModelsimAse(CommandSim, ToolModelsimAse):
 
         vsim_one_liner = vsim_one_liner.replace('\n', ' ')
 
-        vlog_do_lines = [
+        vlog_do_lines += [
             "if {[file exists work]} { vdel -all work; }",
             "vlib work;",
             "quietly set qc 30;",
@@ -263,9 +305,8 @@ class CommandSimModelsimAse(CommandSim, ToolModelsimAse):
             "}",
         ]
 
-        vopt_do_lines = []
         if self.use_vopt:
-            vopt_do_lines = [
+            vopt_do_lines += [
                 "if {[catch { " + vopt_one_liner + " } result] } {",
                 "    echo \"Caught $result\";",
                 "    if {[batch_mode]} {",
@@ -274,7 +315,7 @@ class CommandSimModelsimAse(CommandSim, ToolModelsimAse):
                 "}",
             ]
 
-        vsim_do_lines = [
+        vsim_do_lines += [
             "if {[catch { " + vsim_one_liner + " } result] } {",
             "    echo \"Caught $result\";",
             "    if {[batch_mode]} {",
