@@ -19,6 +19,7 @@ from opencos.eda_base import Tool
 from opencos.commands import (
     CommandSynth, CommandBuild, CommandFList, CommandProj, CommandUpload, CommandOpen
 )
+from opencos.utils.str_helpers import sanitize_defines_for_sh, strip_outer_quotes
 
 class ToolQuartus(Tool):
     '''ToolQuartus used by opencos.eda for --tool=quartus'''
@@ -225,6 +226,18 @@ class CommandSynthQuartus(CommandSynth, ToolQuartus):
         for incdir in self.incdirs:
             tcl_lines.append(f"set_global_assignment -name SEARCH_PATH \"{incdir}\"")
 
+        # Parameters -->  set_parameter -name <Parameter_Name> <Value>
+        for k,v in self.parameters.items():
+            if not isinstance(v, (int, str)):
+                util.warning(f'parameter {k} has value: {v}, parameters must be int/string types')
+            if isinstance(v, int):
+                tcl_lines.append(f"set_parameter -name {k} {v}")
+            else:
+                v = strip_outer_quotes(v.strip('\n'))
+                v = '"' + v + '"'
+                tcl_lines.append(f"set_parameter -name {k} {sanitize_defines_for_sh(v)}")
+
+
         # Add all include directories as user libraries for better include resolution
         for incdir in self.incdirs:
             if os.path.exists(incdir):
@@ -307,7 +320,7 @@ class CommandBuildQuartus(CommandBuild, ToolQuartus):
             'flow-tcl-files': [],
         })
 
-    def do_it(self) -> None: # pylint: disable=too-many-branches,too-many-statements
+    def do_it(self) -> None: # pylint: disable=too-many-branches,too-many-statements,too-many-locals
         # add defines for this job
         self.set_tool_defines()
         self.write_eda_config_and_args()
@@ -340,15 +353,25 @@ class CommandBuildQuartus(CommandBuild, ToolQuartus):
         # create an eda.flist_input.f that we'll pass to flist:
         with open(os.path.join(self.args['work-dir'], 'eda.flist_input.f'),
                   'w', encoding='utf-8') as f:
+
+            # defines
+            for key,value in self.defines.items():
+                if value is None:
+                    f.write(f"+define+{key}\n")
+                else:
+                    f.write(shlex.quote(f"+define+{key}={value}") + "\n")
+
+            # incdirs:
+            for incdir in self.incdirs:
+                f.write(f'+incdir+{incdir}\n')
+
+            # files:
             f.write('\n'.join(self.files_v + self.files_sv + self.files_vhd + ['']))
+
+
         command_list.append('--input-file=eda.flist_input.f')
 
 
-        for key,value in self.defines.items():
-            if value is None:
-                command_list += [ f"+define+{key}" ]
-            else:
-                command_list += [ shlex.quote(f"+define+{key}={value}") ]
 
         # Write out a .sh command for debug
         command_list = util.ShellCommandList(command_list, tee_fpath='run_eda_flist.log')
@@ -487,6 +510,9 @@ class CommandFListQuartus(CommandFList, ToolQuartus):
     def __init__(self, config: dict):
         CommandFList.__init__(self, config=config)
         ToolQuartus.__init__(self, config=self.config)
+        self.args.update({
+            'emit-parameter': False
+        })
 
 
 class CommandProjQuartus(CommandProj, ToolQuartus):
