@@ -118,7 +118,10 @@ class CommandSynthSlangYosys(CommonSynthYosys, ToolSlangYosys):
             params=self.parameters, arg_prefix='-G '
         )
 
-        read_slang_cmd.append(f'--top {self.args["top"]}')
+        # In case --top was not set:
+        if not any(x.startswith('--top') for x in read_slang_cmd):
+            read_slang_cmd.append(f'--top {self.args["top"]}')
+
         return ' '.join(read_slang_cmd)
 
 
