@@ -244,6 +244,11 @@ class VerilatorSim(CommandSim, ToolVerilator):
                 # +define+{k}={v}, but also for SystemVerilog plusargs
                 verilate_command_list += [ f'+define+{k}={sanitize_defines_for_sh(v)}' ]
 
+        # parameters
+        verilate_command_list.extend(
+            self.process_parameters_get_list(arg_prefix='-G')
+        )
+
         if not self.files_sv and not self.files_v:
             if not self.args['stop-before-compile']:
                 self.error(f'{self.target=} {self.files_sv=} and {self.files_v=} are empty,',
